package org.mwolff.converter;

import java.util.ArrayList;
import java.util.List;

/**
 * A generic {@link Converter} to convert with different {@link Populator} classes.
 */
public class GenericConverter implements Converter {

    /**
     *  A list of {@link Populator} classes.
     */
    private List<Populator> populatorlist = new ArrayList<>();

    /**
     * A list of sources to populate.
     */
    private List<Object> sourceList = new ArrayList<>();

    /**
     * For Dependency Injection e.g. Spring
     * @param listToSet A List of Populators.
     */
    public void setPopulatorlist(final List<Populator> listToSet) {
        this.populatorlist = listToSet;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void addPopulator(Populator populator) {
        populatorlist.add(populator);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void addSource(Object source) {
        sourceList.add(source);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void convert(ViewDTO viewDTO) {
        populatorlist.forEach((Populator populator) -> sourceList.forEach((Object object) ->
                populator.convert(object, viewDTO)));
    }
}